-- settingsWidget.lua
-- Written by Habna


-- **v Load settings v**
function LoadSettings()
	settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "HugeBagWidgetSettings" );
	
	-- **v no settings found, create it v**
	if settings == nil then
		WinLocX = screenWidth - WinWidth;
		WinLocY = screenHeight - WinHeight - 70;
		SaveSettings();
	end
	-- **^
	-- **v Load Settings v**

	WinLocX = settings.Location.X;
	WinLocY = settings.Location.Y;

	-- **v Replace HugeBag if out of the screen on load v**
	if ( WinLocY + WinHeight ) > screenHeight then WinLocY = screenHeight - WinHeight end
	-- **^

	WidgetLoc = settings.Location.Loc;
	HideWEsc = settings.Options.HideWEsc;
	StartVisible = settings.Options.StartVisible;
	bcAlpha = settings.BackColor.A;
	bcRed = settings.BackColor.R;
	bcGreen = settings.BackColor.G;
	bcBlue = settings.BackColor.B;
	SortLeft = settings.ButtonPos.Sort;
	SearchLeft = settings.ButtonPos.Search;
	MergeLeft = settings.ButtonPos.Merge;
	-- **^
	-- **v Check version so settings can be updated (if a user used an old version before the last release)
	if ( settings.Version ~= Version ) then
		Updatedsettings = {};

		Updatedsettings.Location = {};
		Updatedsettings.Location.X = WinLocX;
		Updatedsettings.Location.Y = WinLocY;

		if settings.Location.Loc == nil then
			Updatedsettings.Location.Loc = "right";
		else
			Updatedsettings.Location.Loc = WidgetLoc;
		end
		
		Updatedsettings.Options = {};
		if settings.Options.HideWEsc == nil then
			Updatedsettings.Options.HideWEsc = false;
		else
			Updatedsettings.Options.HideWEsc = HideWEsc;
		end

		if settings.Options.StartVisible == nil then
			Updatedsettings.Options.StartVisible = false;
		else
			Updatedsettings.Options.StartVisible = StartVisible;
		end
		
		Updatedsettings.BackColor = {};
		Updatedsettings.BackColor.A = bcAlpha;
		Updatedsettings.BackColor.R = bcRed;
		Updatedsettings.BackColor.G = bcGreen;
		Updatedsettings.BackColor.B = bcBlue;

		Updatedsettings.ButtonPos.Sort = SortLeft;
		Updatedsettings.ButtonPos.Search = SearchLeft;
		Updatedsettings.ButtonPos.Merge = MergeLeft;

		if settings.WidgetLoc == nil then
			Updatedsettings.WidgetLoc = right;
		else
			Updatedsettings.WidgetLoc = WidgetLoc;
		end

		Updatedsettings.Version = Version;
		Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagWidgetSettings", Updatedsettings );
	end
	-- **^
end
-- **^
-- **v Save settings v**
function SaveSettings()
	settings = {};
	settings.Version = Version;

	settings.Options = {};
	settings.Options.StartVisible = StartVisible;
	settings.Options.HideWEsc = HideWEsc;

	settings.Location = {};
	settings.Location.X = WinLocX;
	settings.Location.Y = WinLocY;
	settings.Location.Loc = WidgetLoc;

	settings.BackColor = {};
	settings.BackColor.A = bcAlpha;
	settings.BackColor.R = bcRed;
	settings.BackColor.G = bcGreen;
	settings.BackColor.B = bcBlue;

	settings.ButtonPos = {};
	settings.ButtonPos.Sort = SortLeft;
	settings.ButtonPos.Search = SearchLeft;
	settings.ButtonPos.Merge = MergeLeft;

	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagWidgetSettings", settings );

	Modesettings = {};
	Modesettings.Widget = Widget;
	Turbine.PluginData.Save( Turbine.DataScope.Character, "HugeBagMode", Modesettings );
end
-- **^
-- **v Reset All Settings v**
function ResetSettings()
	WinLocX = screenWidth - WinWidth - 1;
	WinLocY = screenHeight - WinHeight - 69;
	frmMain:SetPosition( WinLocX, WinLocY );
	WidgetLoc = "right";
	StartVisible = false;
	HideWEsc = true;
	Widget = Widget;
	bcAlpha, bcRed, bcGreen, bcBlue = 0.3, 0.3, 0.3, 0.3;
	itemListBox:SetBackColor( Turbine.UI.Color( bcAlpha, bcRed, bcGreen, bcBlue ) );
	if ( windowOpen ) and ( not StartVisible ) then
		frmMain:SetVisible( true );
		slideCtr:SetWantsUpdates(true);
	end
	SaveSettings()
	write( "HugeBag: All my settings was set back to default" );
end
-- **^
--^ FUNCTIONS/METHODS SECTION ^--